# PyColl

PyColl package is a collection of functions which can be used find the area of Square, Rectangle, Triangle and Parallelogram.

## Installations

Type or Copy the pip code and paste it into your terminal.

     pip install pycall

## Usage

To use this pycoll module in to your program, you can simply import the functions which you want to use:

    import pycoll as pc
    
    pc.area_parallelogram(15, 20)
    
**Functions available in the package:**

 

    #pass one parameter
    pycoll.area_square(side) 
    
    #pass two parameter
    pycoll.area_rectangle(length, breadth)
    
    #pass two parameter
    pycoll.area_triangle(base, height)
    
    #pass two parameter
    pycoll.area_parallelogram(base, height)

## Additional links

You can also get it from pypi.org

[https://pypi.org/project/pycoll/](https://pypi.org/project/pycoll/)
